.. _roadmap:

Dask-ML Roadmap
===============

Dask-ML wants to enable scalable machine learning in Python. It aims to do so by

1. Working with existing libraries within the Python ecosystem
2. Using the features of Dask to scale computation to larger datasets and larger
   problems

We'll use these two values to guide what's appropriate for inclusion in Dask-ML.

A list of open issues on our roadmap can be found `on GitHub <https://github.com/dask/dask-ml/labels/Roadmap>`_.
